@@ -118,6 +118,7 @@ impl Args {
                                         println!("{}", man::MAN_PAGE);
                                         exit(0);
                                     },
+                                    b'k' => (),
                                     b'p' => self.flags |= PIPE_IS_ENABLED,
                                     b'q' => quote_enabled = true,
                                     b's' => self.flags |= QUIET_MODE,
@@ -142,6 +143,7 @@ impl Args {
                                     println!("{}", man::MAN_PAGE);
                                     exit(0);
                                 },
+                                "keep-order" => (),
                                 "group" => (),
                                 "joblog" => {
                                     let file = arguments.get(index).ok_or(ParseErr::JoblogNoValue)?;
@@ -362,7 +364,11 @@ fn quote_inputs(input: &str) -> String {
 fn write_stdin_to_disk(max_args: usize, mut unprocessed_path: PathBuf, inputs_are_commands: bool,
     quote_enabled: bool) -> Result<usize, ParseErr>
 {
-    println!("parallel: reading inputs from standard input");
+    // Write a message to standard error that inputs are being read from standard input
+    let stderr = io::stderr();
+    let mut stderr = stderr.lock();
+    let _ = stderr.write(b"parallel: reading inputs from standard input\n");
+
     unprocessed_path.push("unprocessed");
     let disk_buffer = fs::OpenOptions::new().truncate(true).write(true).create(true).open(&unprocessed_path)
         .map_err(|why| ParseErr::File(FileErr::Open(unprocessed_path.clone(), why)))?;
@@ -377,9 +383,7 @@ fn write_stdin_to_disk(max_args: usize, mut unprocessed_path: PathBuf, inputs_ar
             input.map(|x| quote_command(&x))
         })
     } else {
-        Box::new(|input: io::Result<String>| -> io::Result<String> {
-            input
-        })
+        Box::new(|input: io::Result<String>| -> io::Result<String> { input })
     };
 
     let stdin = io::stdin();
@@ -452,7 +456,7 @@ fn write_inputs_to_disk(lists: Vec<Vec<String>>, current_inputs: Vec<String>, ma
             disk_buffer.write(iter.next().unwrap().as_bytes())
                 .map_err(|why| FileErr::Write(unprocessed_path.clone(), why))?;
             for element in iter {
-                disk_buffer.write(b"\\ ").and_then(|_| disk_buffer.write(element.as_bytes()))
+                disk_buffer.write(b" ").and_then(|_| disk_buffer.write(element.as_bytes()))
                     .map_err(|why| FileErr::Write(unprocessed_path.clone(), why))?;
             }
 
@@ -466,7 +470,7 @@ fn write_inputs_to_disk(lists: Vec<Vec<String>>, current_inputs: Vec<String>, ma
                 disk_buffer.write(iter.next().unwrap().as_bytes())
                     .map_err(|why| FileErr::Write(unprocessed_path.clone(), why))?;
                 for element in iter {
-                    disk_buffer.write(b"\\ ").and_then(|_| disk_buffer.write(element.as_bytes()))
+                    disk_buffer.write(b" ").and_then(|_| disk_buffer.write(element.as_bytes()))
                         .map_err(|why| FileErr::Write(unprocessed_path.clone(), why))?;
                 }
                 disk_buffer.write(b"\n")
@@ -485,17 +489,17 @@ fn write_inputs_to_disk(lists: Vec<Vec<String>>, current_inputs: Vec<String>, ma
                         .map_err(|why| FileErr::Write(unprocessed_path.clone(), why))?;
 
                     for element in iter {
-                        disk_buffer.write(b"\\ ").and_then(|_| disk_buffer.write(element.as_bytes()))
+                        disk_buffer.write(b" ").and_then(|_| disk_buffer.write(element.as_bytes()))
                             .map_err(|why| FileErr::Write(unprocessed_path.clone(), why))?;
                     }
                 } else if max_args_index == 1 {
                     max_args_index = max_args;
-                    disk_buffer.write(b"\\ ")
+                    disk_buffer.write(b" ")
                         .and_then(|_| disk_buffer.write(iter.next().unwrap().as_bytes()))
                         .map_err(|why| FileErr::Write(unprocessed_path.clone(), why))?;
 
                     for element in iter {
-                        disk_buffer.write(b"\\ ").and_then(|_| disk_buffer.write(element.as_bytes()))
+                        disk_buffer.write(b" ").and_then(|_| disk_buffer.write(element.as_bytes()))
                             .map_err(|why| FileErr::Write(unprocessed_path.clone(), why))?;
                     }
 
@@ -503,12 +507,12 @@ fn write_inputs_to_disk(lists: Vec<Vec<String>>, current_inputs: Vec<String>, ma
                         .map_err(|why| FileErr::Write(unprocessed_path.clone(), why))?;
                 } else {
                     max_args_index -= 1;
-                    disk_buffer.write(b"\\ ")
+                    disk_buffer.write(b" ")
                         .and_then(|_| disk_buffer.write(iter.next().unwrap().as_bytes()))
                         .map_err(|why| FileErr::Write(unprocessed_path.clone(), why))?;
 
                     for element in iter {
-                        disk_buffer.write(b"\\ ").and_then(|_| disk_buffer.write(element.as_bytes()))
+                        disk_buffer.write(b" ").and_then(|_| disk_buffer.write(element.as_bytes()))
                             .map_err(|why| FileErr::Write(unprocessed_path.clone(), why))?;
                     }
                 }
@@ -529,7 +533,7 @@ fn write_inputs_to_disk(lists: Vec<Vec<String>>, current_inputs: Vec<String>, ma
 
             while index != max_index {
                 disk_buffer.write(chunk[index].as_bytes())
-                    .and_then(|_| disk_buffer.write(b"\\ "))
+                    .and_then(|_| disk_buffer.write(b" "))
                     .map_err(|why| FileErr::Write(unprocessed_path.clone(), why))?;
                 index += 1;
             }
