@@ -3,7 +3,7 @@ use arguments::errors::{FileErr};
 use super::InputIteratorErr;
 use itoa;
 use time;
-use std::io::{self, Write};
+use std::io::{self, Write, Read};
 use std::path::{Path, PathBuf};
 use std::str;
 
@@ -44,20 +44,20 @@ impl ETA {
 /// The `InputIterator` tracks the total number of arguments, the current argument counter, and
 /// takes ownership of an `InputBuffer` which buffers input arguments from the disk when arguments
 /// stored in memory are depleted.
-pub struct InputIterator {
+pub struct InputIterator<IO: Read> {
     pub total_arguments: usize,
     pub curr_argument:   usize,
     pub completed:       usize,
     start_time:          u64,
     average_time:        u64,
-    input_buffer:        InputBuffer,
+    input_buffer:        InputBuffer<IO>,
 }
 
-impl InputIterator {
-    pub fn new(path: &Path, args: usize) -> Result<InputIterator, FileErr> {
+impl<IO: Read> InputIterator<IO> {
+    pub fn new(path: &Path, file: IO, args: usize) -> Result<InputIterator<IO>, FileErr> {
         // Create an `InputBuffer` from the unprocessed file.
-        let disk_buffer = DiskBuffer::new(path).read()
-            .map_err(|why| FileErr::Open(PathBuf::from(path), why))?;
+        let disk_buffer = DiskBufferReader::new(path, file);
+
         let input_buffer = InputBuffer::new(disk_buffer)?;
 
         Ok(InputIterator {
@@ -130,7 +130,7 @@ impl InputIterator {
 }
 
 // Implement the `Iterator` trait for `InputIterator` to gain access to all the `Iterator` methods for free.
-impl Iterator for InputIterator {
+impl<IO: Read> Iterator for InputIterator<IO> {
     type Item = Result<String, InputIteratorErr>;
 
     fn next(&mut self) -> Option<Result<String, InputIteratorErr>> {
@@ -169,19 +169,19 @@ impl Iterator for InputIterator {
 /// Higher level buffer implementation which keeps track of how many inputs are currently
 /// stored in the buffer, where all of the indices of the input delimiters are, and which
 /// segment of the complete set of arguments are currently buffered.
-struct InputBuffer {
+struct InputBuffer<IO: Read> {
     index:       usize,
     start:       usize,
     end:         usize,
     capacity:    usize,
-    disk_buffer: DiskBufferReader,
+    disk_buffer: DiskBufferReader<IO>,
     indices:     [usize; BUFFER_SIZE / 2],
 }
 
-impl InputBuffer {
+impl<IO: Read> InputBuffer<IO> {
     /// Takes ownership of a `DiskBufferReader` and transforms it into a higher level
     /// `InputBuffer` which will track additional information about the disk buffer.
-    fn new(mut unprocessed: DiskBufferReader) -> Result<InputBuffer, FileErr> {
+    fn new(mut unprocessed: DiskBufferReader<IO>) -> Result<InputBuffer<IO>, FileErr> {
         unprocessed.buffer(0).map_err(|why| FileErr::Read(unprocessed.path.clone(), why))?;
         let bytes_read = unprocessed.capacity;
 
@@ -203,7 +203,7 @@ impl InputBuffer {
 
 /// Counts the number of arguments that are stored in the buffer, marking the location of
 /// the indices and the actual capacity of the buffer's useful information.
-fn count_arguments(buffer: &mut InputBuffer, bytes_read: usize) {
+fn count_arguments<IO: Read>(buffer: &mut InputBuffer<IO>, bytes_read: usize) {
     let mut newlines = 1;
     buffer.capacity  = 0;
 
@@ -217,12 +217,19 @@ fn count_arguments(buffer: &mut InputBuffer, bytes_read: usize) {
     buffer.end += newlines;
 }
 
-#[test]
-fn test_input_iterator() {
-    let iterator = InputIterator::new(Path::new("tests/buffer.dat"), 4096).unwrap();
-    assert_eq!(0,  iterator.input_buffer.start);
-    assert_eq!(1859, iterator.input_buffer.end);
-    for (actual, expected) in iterator.zip((1..4096)) {
-        assert_eq!(actual.unwrap(), expected.to_string());
+#[cfg(test)]
+mod tests {
+    use super::*;
+    use std::fs::File;
+
+    #[test]
+    fn test_input_iterator() {
+        let file = File::open("tests/buffer.dat").unwrap();
+        let iterator = InputIterator::new(Path::new("tests/buffer.dat"), file, 4096).unwrap();
+        assert_eq!(0, iterator.input_buffer.start);
+        assert_eq!(1859, iterator.input_buffer.end);
+        for (actual, expected) in iterator.zip((1..4096)) {
+            assert_eq!(actual.unwrap(), expected.to_string());
+        }
     }
 }
